==> ejc-labor-api-3.0.0-20241226.092540-319-sources.jar: com/ejianc/business/labor/vo/PointTicketsDetailVO.java <==
package com.ejianc.business.labor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 点工单-人员信息
 * 
 * @author generator
 * 
 */
public class PointTicketsDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表id
    private Long workerId; // 工人id
    private String name; // 姓名
    private Integer sex; // 性别
    private String idCard; // 身份证号
    private String phone; // 手机号
    private String remark; // 备注
    private String workType; // 工种
    private String workTypeName; // 工种

    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-labor-api-3.0.0-20250403.082329-340-sources.jar: com/ejianc/business/labor/vo/PointTicketsDetailVO.java <==
package com.ejianc.business.labor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 点工单-人员信息
 * 
 * @author generator
 * 
 */
public class PointTicketsDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pid; // 主表id
    private Long workerId; // 工人id
    private String name; // 姓名
    private Integer sex; // 性别
    private String idCard; // 身份证号
    private String phone; // 手机号
    private String remark; // 备注
    private String workType; // 工种
    private String workTypeName; // 工种
    private BigDecimal actualDays; // 实际出勤天数 打卡记录无值默认为1天，点工单按实际录入天数，可以录入小数

    public BigDecimal getActualDays() {
        return actualDays;
    }

    public void setActualDays(BigDecimal actualDays) {
        this.actualDays = actualDays;
    }
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getSex() {
        return sex;
    }

    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
